
function demo_colebrook

% in questa demo studiamo l'equazione di colebrook
% 1/sqrt(lambda)=-2*log10( (e/3.51*d) + 2.52/(NR*sqrt(lambda)) )
% dove e,d,NR sono fissati dal problema e "lambda" e l'incognita

% ---- parametri punto fisso ----
x0=1;
toll=10^(-8);
maxit=100000;

% ---- parametri colebrook ----
e=1;
d=1;
NR=10^1;

% ---- metodo scelto ----

% risolviamo x=-2*log10( (e/3.51*d) + 2.52*x/NR ) (per x >= 0) e poi
% poniamo x=1/sqrt(lambda) ovvero lambda=1/x^2.
phi=@(x) -2*log10( (e/3.51*d) + 2.52*x/NR );
[xv, step, flag] = puntofisso (phi, x0, toll, maxit);


% ---- statistiche ----

fprintf('\n \t valore flag: %1.0f',flag);
fprintf('\n \t soluzione  : %1.15e',xv(end));
fprintf('\n \t iterazioni : %8.0f',length(xv));
fprintf('\n \t step       : %1.1e',step(end));
fprintf('\n \t abs(x-phi(x)): %1.1e',abs(xv(end)-phi(xv(end))));
fprintf('\n \n');